@@ -637,12 +637,15 @@ if (! window._OQAjaxQueryLoaded)
       if (this.disabled) return true;
       var val = $(this).val();
 
-      if (this.name && /^arg\_/.test(this.name)) {
-        var name = this.name.replace(/^arg\_/,'');
-        if (/\s/.test(val) || val=='') {
-          if (/\"/.test(val)) val = "'"+val+"'";   
-          else val = '"'+val+'"';   
+      if (this.name && /^\_nf\_arg\_(.*)/.test(this.name)) {
+        var name = RegExp.$1;
+
+        // if not simple literal, we need to quote it
+        if (! /^\w+$/.test(val)) {
+          if (! /\'/.test(val)) val = "'"+val+"'";
+          else val = '"'+val.replace(/\"/g,'')+'"';
         }
+
         //if last character of filter string is an open paren don't add a comma
         if (! /\($/.test(newfilter)) newfilter += ',';
         newfilter += name + ',' + val;
@@ -650,7 +653,7 @@ if (! window._OQAjaxQueryLoaded)
       else if ($(this).is('select.rexp')) {
         if (val) newfilter += ' '+val;
       }
-      else if ($(this).is('input.rexp')) {
+      else if ($(this).is('input.rexp') && $(this).is(':visible')) {
         if (! /\'/.test(val)) val = "'"+val+"'";
         else if (! /\"/.test(val)) val = '"'+val+'"';
         else val = '"'+val.replace(/\"/g,'')+'"';
@@ -720,7 +723,8 @@ if (! window._OQAjaxQueryLoaded)
   var buildParamMap = function($form) {
     var dat={};
     $('input,select',$form[0]).each(function(){
-      if (this.name) dat[this.name]=$(this).val();
+      // ignore named filter arguments
+      if (this.name && ! /^\_nf\_arg\_/.test(this.name)) dat[this.name]=$(this).val();
     });
     return dat;
   };
